pub enum ReleaseComparator {
Eq,
Gt,
Gte,
Lt,
Lte,
Unsupported,
}Expand description
The comparison a ReleaseCondition applies.
Variants
Eq
The version of the field is equal to the value.
Unlike EqCondition, this ignores the build code of the release.
Gt
The version of the field is greater than the value.
Gte
The version of the field is greater than or equal to the value.
Lt
The version of the field is less than the value.
Lte
The version of the field is less than or equal to the value.
Unsupported
An unsupported comparator for future compatibility. It never matches.