pub struct IpNetworks(/* private fields */);Expand description
A set of IP addresses and CIDR ranges.
Serialized as a list of strings such as "10.0.0.1" or "10.0.0.0/8". Entries that do not
parse as an address or a range are skipped while deserializing, like invalid glob patterns.
Implementations